################################################################################
Name:             pki-console
################################################################################

Summary:          Dogtag PKI Console Package
URL:              http://www.dogtagpki.org/
License:          GPLv2

%if 0%{?rhel}
Version:          10.6.2
Release:          2%{?_timestamp}%{?_commit_id}%{?dist}
%else
Version:          10.6.2
Release:          2%{?_timestamp}%{?_commit_id}%{?dist}
%endif

# To create a tarball from a version tag:
# $ git archive \
#     --format=tar.gz \
#     --prefix pki-<version>/ \
#     -o pki-<version>.tar.gz \
#     <version tag>
Source: https://github.com/dogtagpki/pki/archive/v%{version}/pki-%{version}.tar.gz

# To create a patch for all changes since a version tag:
# $ git format-patch \
#     --stdout \
#     <version tag> \
#     > pki-VERSION-RELEASE.patch
# Patch: pki-VERSION-RELEASE.patch

################################################################################
# NSS
################################################################################

%if 0%{?fedora} >= 28 || 0%{?rhel} > 7
%global nss_default_db_type sql
%else
%global nss_default_db_type dbm
%endif

################################################################################
# Python
################################################################################

# Python 2 packages
%if 0%{!?with_python2:1}
%if 0%{?rhel} && 0%{?rhel} <= 7 || 0%{?fedora} && 0%{?fedora} <= 28
%global with_python2 1
%else
%global with_python2 0
%endif
%endif

# Python 3 packages
%if 0%{!?with_python3:1}
%if 0%{?rhel} && 0%{?rhel} <= 7
%global with_python3 0
%else
%global with_python3 1
%endif
%endif

# Use Python 3 for all commands?
%if 0%{!?with_python3_default:1}
%if 0%{?rhel} && 0%{?rhel} <= 7 || 0%{?fedora} && 0%{?fedora} <= 27
%global with_python3_default 0
%else
%global with_python3_default 1
%endif
%endif

################################################################################
# Java
################################################################################

%define java_home %{_usr}/lib/jvm/jre-1.8.0-openjdk

################################################################################
# Tomcat
################################################################################

%if 0%{?rhel} && 0%{?rhel} <= 7
%global app_server tomcat-7.0
%else
%if 0%{?fedora} && 0%{?fedora} <= 27
%global app_server tomcat-8.0
%else
%global app_server tomcat-8.5
%endif
%endif

################################################################################
# RESTEasy
################################################################################

%if 0%{?rhel} && 0%{?rhel} <= 7
%define jaxrs_api_jar /usr/share/java/resteasy-base/jaxrs-api.jar
%define resteasy_lib /usr/share/java/resteasy-base
%else
%define jaxrs_api_jar /usr/share/java/jboss-jaxrs-2.0-api.jar
%define resteasy_lib /usr/share/java/resteasy
%endif

################################################################################
# PKI
################################################################################

%bcond_without    javadoc

# ignore unpackaged files
%define _unpackaged_files_terminate_build 0

BuildArch:        noarch

################################################################################
# Build Dependencies
################################################################################

# autosetup
BuildRequires:    git

BuildRequires:    cmake >= 2.8.9-1
BuildRequires:    gcc-c++
BuildRequires:    zip
BuildRequires:    java-1.8.0-openjdk-devel
BuildRequires:    redhat-rpm-config
BuildRequires:    ldapjdk >= 4.19-5
BuildRequires:    apache-commons-cli
BuildRequires:    apache-commons-codec
BuildRequires:    apache-commons-io
BuildRequires:    apache-commons-lang
BuildRequires:    jakarta-commons-httpclient
BuildRequires:    slf4j
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires:    slf4j-jdk14
%endif
BuildRequires:    nspr-devel
BuildRequires:    nss-devel >= 3.36.1

%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:    nuxwdog-client-java >= 1.0.3-7
%else
BuildRequires:    nuxwdog-client-java >= 1.0.3-13
%endif

BuildRequires:    openldap-devel
BuildRequires:    pkgconfig
BuildRequires:    policycoreutils

%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:    python-lxml
BuildRequires:    python-sphinx
%else
%if 0%{?fedora} && 0%{?fedora} <= 28
BuildRequires:    python2-lxml
BuildRequires:    python2-sphinx
%else
BuildRequires:    python3-lxml
BuildRequires:    python3-sphinx
%endif
%endif

BuildRequires:    velocity
BuildRequires:    xalan-j2
BuildRequires:    xerces-j2

%if 0%{?rhel} && 0%{?rhel} <= 7
# 'resteasy-base' is a subset of the complete set of
# 'resteasy' packages and consists of what is needed to
# support the PKI Restful interface on certain RHEL platforms
BuildRequires:    resteasy-base-atom-provider >= 3.0.6-1
BuildRequires:    resteasy-base-client >= 3.0.6-1
BuildRequires:    resteasy-base-jaxb-provider >= 3.0.6-1
BuildRequires:    resteasy-base-jaxrs >= 3.0.6-1
BuildRequires:    resteasy-base-jaxrs-api >= 3.0.6-1
BuildRequires:    resteasy-base-jackson-provider >= 3.0.6-1
%else
BuildRequires:    jboss-annotations-1.2-api
BuildRequires:    jboss-jaxrs-2.0-api
BuildRequires:    jboss-logging
BuildRequires:    resteasy-atom-provider >= 3.0.17-1
BuildRequires:    resteasy-client >= 3.0.17-1
BuildRequires:    resteasy-jaxb-provider >= 3.0.17-1
BuildRequires:    resteasy-core >= 3.0.17-1
BuildRequires:    resteasy-jackson-provider >= 3.0.17-1
%endif

%if 0%{?with_python2}
%if 0%{?rhel} && 0%{?rhel} <= 7
# no pylint
%else
BuildRequires:    pylint
%if 0%{?fedora} && 0%{?fedora} <= 27
BuildRequires:    python-flake8 >= 2.5.4
BuildRequires:    pyflakes >= 1.2.3
%else
BuildRequires:    python2-flake8 >= 2.5.4
BuildRequires:    python2-pyflakes >= 1.2.3
%endif
%endif
%endif  # with_python2

%if 0%{?with_python3}
BuildRequires:    python3-pylint
BuildRequires:    python3-flake8 >= 2.5.4
BuildRequires:    python3-pyflakes >= 1.2.3
%endif  # with_python3

%if 0%{?with_python2}
BuildRequires:    python2
BuildRequires:    python2-devel
BuildRequires:    python2-cryptography
%if 0%{?rhel} && 0%{?rhel} <= 7 || 0%{?fedora} && 0%{?fedora} <= 27
BuildRequires:    python-nss
BuildRequires:    python-requests >= 2.6.0
BuildRequires:    python-six
BuildRequires:    libselinux-python
BuildRequires:    policycoreutils-python
BuildRequires:    python-ldap
%else
BuildRequires:    python2-nss
BuildRequires:    python2-requests >= 2.6.0
BuildRequires:    python2-six
BuildRequires:    python2-libselinux
BuildRequires:    python2-policycoreutils
BuildRequires:    python2-ldap
%endif
%if 0%{?rhel} && 0%{?rhel} <= 7
# no policycoreutils-python-utils
%else
BuildRequires:    policycoreutils-python-utils
%endif
%endif  # with_python2

%if 0%{?with_python3}
BuildRequires:    python3
BuildRequires:    python3-devel
BuildRequires:    python3-cryptography
BuildRequires:    python3-lxml
%if 0%{?rhel} && 0%{?rhel} <= 7 || 0%{?fedora} && 0%{?fedora} <= 27
# no python3-libselinux
%else
BuildRequires:    python3-libselinux
%endif
BuildRequires:    python3-nss
BuildRequires:    python3-pyldap
BuildRequires:    python3-requests >= 2.6.0
BuildRequires:    python3-six
%endif  # with_python3

BuildRequires:    junit
BuildRequires:    jpackage-utils >= 0:1.7.5-10
%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:    jss >= 4.4.0-11
BuildRequires:    tomcatjss >= 7.2.1-4
%else
BuildRequires:    jss >= 4.5.0-0.1
BuildRequires:    tomcatjss >= 7.3.0
%endif
BuildRequires:    systemd-units

%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:    tomcat >= 7.0.69
%else
%if 0%{?fedora} && 0%{?fedora} <= 27
BuildRequires:    tomcat >= 8.0.49
%else
%if 0%{?fedora} && 0%{?fedora} <= 28
BuildRequires:    tomcat >= 1:8.5.23
%else
BuildRequires:    tomcat >= 1:9.0.7
%endif
%endif
%endif

# additional build requirements needed to build native 'tpsclient'
# REMINDER:  Revisit these once 'tpsclient' is rewritten as a Java app
BuildRequires:    apr-devel
BuildRequires:    apr-util-devel
BuildRequires:    cyrus-sasl-devel
BuildRequires:    httpd-devel >= 2.4.2
BuildRequires:    pcre-devel
BuildRequires:    systemd
BuildRequires:    zlib
BuildRequires:    zlib-devel

# Required by pki-console
BuildRequires:    idm-console-framework >= 1.1.17-4

Requires:         idm-console-framework >= 1.1.17-4
Requires:         java-1.8.0-openjdk
Requires:         ldapjdk >= 4.19-5
Requires:         pki-base-java >= %{version}
Requires:         pki-console-theme >= %{version}
Requires:         jpackage-utils >= 1.7.5-10

%description
The PKI Console is a Java application used to administer PKI server.

For deployment purposes, a PKI Console requires ONE AND ONLY ONE of the
following "Mutually-Exclusive" PKI Theme packages:

  * dogtag-pki-console-theme (Dogtag Certificate System deployments)
  * redhat-pki-console-theme (Red Hat Certificate System deployments)

################################################################################
%prep
################################################################################

%autosetup -n pki-%{version} -p 1 -S git

################################################################################
%build
################################################################################

%{__mkdir_p} build
cd build
%cmake \
    --no-warn-unused-cli \
    -DVERSION=%{version}-%{release} \
    -DVAR_INSTALL_DIR:PATH=/var \
    -DJAVA_HOME=%{java_home} \
    -DJAVA_LIB_INSTALL_DIR=%{_jnidir} \
    -DSYSTEMD_LIB_INSTALL_DIR=%{_unitdir} \
    -DAPP_SERVER=%{app_server} \
    -DJAXRS_API_JAR=%{jaxrs_api_jar} \
    -DRESTEASY_LIB=%{resteasy_lib} \
    -DNSS_DEFAULT_DB_TYPE=%{nss_default_db_type} \
    -DBUILD_PKI_CORE:BOOL=ON \
    -DWITH_PYTHON2:BOOL=%{?with_python2:ON}%{!?with_python2:OFF} \
    -DWITH_PYTHON3:BOOL=%{?with_python3:ON}%{!?with_python3:OFF} \
%if %{?with_python3_default}
    -DWITH_PYTHON3_DEFAULT:BOOL=ON \
%endif
    -DWITH_TEST:BOOL=OFF \
    -DWITH_SERVER:BOOL=OFF \
    -DWITH_JAVADOC:BOOL=OFF \
    -DBUILD_PKI_CONSOLE:BOOL=ON \
    ..

################################################################################
%install
################################################################################

cd build

# Do not use _smp_mflags to preserve build order
%{__make} \
    VERBOSE=%{?_verbose} \
    CMAKE_NO_VERBOSE=1 \
    DESTDIR=%{buildroot} \
    INSTALL="install -p" \
    --no-print-directory \
    all install

################################################################################
%files
################################################################################

%defattr(-,root,root,-)
%doc base/console/LICENSE
%{_bindir}/pkiconsole
%{_javadir}/pki/pki-console.jar

################################################################################
%changelog
* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 10.6.2-2
- Rebuilt for Python 3.7


* Fri Jun 15 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.2-1
- Rebased to PKI 10.6.2

* Wed May 30 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.1-3
- Updated JSS dependency
- Updated Tomcat dependency
- Fixed rpmlint warnings

* Fri May 4 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.1-2
- Bugzilla #1574711: pki-tools cannot be installed on current Rawhide
- Fixed rpmlint warnings

* Thu May 3 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.1-1
- Rebased to PKI 10.6.1
- Bugzilla #1559047: pki-core misses a dependency to pki-symkey
- Bugzilla #1573094: FreeIPA external CA installation fails

* Wed Apr 11 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.0-1
- Updated project URL
- Cleaned up spec file
- Rebased to PKI 10.6.0 final

* Thu Mar 29 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.0-0.3
- Rebased to PKI 10.6.0 beta2

* Thu Mar 15 2018 Dogtag PKI Team <pki-devel@redhat.com> - 10.6.0-0.2
- Rebased to PKI 10.6.0 beta

